/// <reference path="../coveo-search-ui/CoveoJsSearch.d.ts" />
declare module "UserContext/UserContextHandler" {
    export interface IUserContext {
        [key: string]: string;
    }
    export default class UserContextHandler implements IUserContextHandler {
        private static invalidCharacters;
        private context;
        constructor();
        initializeContext(context: IUserContext): IUserContextHandler;
        setContext(key: string, value: string): IUserContextHandler;
        getContext(): IUserContext;
        private replaceInvalidCharacterInContext(context);
        private replaceInvalidCharacters(key);
    }
    export interface IUserContextHandler {
        initializeContext(context: IUserContext): IUserContextHandler;
        setContext(key: string, value: string): IUserContextHandler;
        getContext(): IUserContext;
    }
}
declare module "Base/EndpointCaller" {
    import * as Coveo from "coveo-search-ui";
    import IStringMap = Coveo.IStringMap;
    export default class EndpointCaller<T> implements IEndpointCaller<T> {
        private endpointCaller;
        constructor(endpointCaller?: Coveo.EndpointCaller);
        sendPost(url: string, postData: IStringMap<string>): Promise<Coveo.ISuccessResponse<T>>;
    }
    export interface IEndpointCaller<T> {
        sendPost(url: string, postData: IStringMap<string>): Promise<Coveo.ISuccessResponse<T>>;
    }
}
declare module "Base/Utilities" {
    export default class Utilities {
        static appendTrailingSlash(url: string): string;
    }
}
declare module "Base/Analytics/SitecoreAnalyticsHandler" {
    import Coveo = require("coveo-search-ui");
    import { IEndpointCaller } from "Base/EndpointCaller";
    export default class SitecoreAnalyticsHandler implements ISitecoreAnalyticsHandler {
        private endpointCaller;
        private options;
        constructor(options: ISitecoreAnalyticsHandlerOptions, endpointCaller?: IEndpointCaller<any>);
        registerSitecoreAnalytics(domElement: Coveo.Dom, windowReference?: Window): void;
        postAnalytics(eventAction: string, eventType: string, eventData: any): void;
    }
    export interface ISitecoreAnalyticsHandler {
        registerSitecoreAnalytics(domElement: Coveo.Dom, windowReference?: Window): void;
        postAnalytics(eventAction: string, eventType: string, eventData: any): void;
    }
    export interface ISitecoreAnalyticsHandlerOptions {
        analyticsEndpointUri: string;
        sitecoreItemId: string;
        sendToSitecoreAnalytics: boolean;
    }
}
declare module "Base/SearchEndpointHelper" {
    export interface ISitecoreEndpointConfiguration {
        restEndpointUri: string;
        sitecoreItemUri: string;
        siteName: string;
    }
    export default class SearchEndpointHelper {
        static initializeEndpoint(options: ISitecoreEndpointConfiguration): void;
    }
}
declare module "Base/Sorts/DefaultSortHandler" {
    import * as Coveo from "coveo-search-ui";
    export default class DefaultSortHandler implements IDefaultSortHandler {
        private fieldSortType;
        private defaultSortOptions;
        constructor(defaultSortOptions: IDefaultSortOptions);
        addSortCriteriaToQuery(queryBuilder: Coveo.QueryBuilder): void;
    }
    export interface IDefaultSortHandler {
        addSortCriteriaToQuery(queryBuilder: Coveo.QueryBuilder): void;
    }
    export interface IDefaultSortOptions {
        defaultSortType: string;
        defaultSortField: string;
        defaultSortCriteriaNoSpace: string;
        defaultSortCriteriaLowercase: string;
    }
}
declare module "Base/Rules/ExpressionHelperOptions" {
    export interface ISearchExpressionOptions extends ISearchFilterExpressionOptions, ISearchBoostExpressionOptions, ISourcesExpressionOptions, IExternalCollectionsExpressionOptions, IExternalContentFromCurrentTabOptions {
    }
    export interface IFilterExpressionOptions extends IExternalCollectionsExpressionOptions, ISearchExpressionOptions, IExternalContentExpressionOptions, IContextFilterExpressionOptions {
    }
    export interface IContextFilterExpressionOptions extends ICurrentCultureOptions, ICurrentVersionOptions {
    }
    export interface ICurrentCultureOptions {
        filterResultsOnCurrentCulture: boolean;
        clientLanguageFieldName?: string;
        clientLanguageName?: string;
    }
    export interface ICurrentVersionOptions {
        filterResultOnLatestVersion: boolean;
        latestVersionFieldName?: string;
    }
    export interface IExternalContentExpressionOptions extends IExternalCollectionsExpressionOptions, IExternalSourcesExpressionOptions, IExternalContentFromCurrentTabOptions {
    }
    export interface ISourcesExpressionOptions extends IExternalSourcesExpressionOptions {
        indexSourceName?: string;
    }
    export interface ISearchFilterExpressionOptions {
        filterExpression: string;
    }
    export interface ISearchBoostExpressionOptions {
        boostExpressions: string;
    }
    export interface IExternalCollectionsExpressionOptions {
        externalCollections: string[];
    }
    export interface IExternalSourcesExpressionOptions {
        externalSources: string[];
    }
    export interface IExternalContentFromCurrentTabOptions {
        externalSourcesFromCurrentTab: string[];
        externalCollectionsFromCurrentTab: string[];
    }
}
declare module "Base/PluginOptions" {
    import { ISitecoreAnalyticsHandlerOptions } from "Base/Analytics/SitecoreAnalyticsHandler";
    import { ISitecoreEndpointConfiguration } from "Base/SearchEndpointHelper";
    import { IDefaultSortOptions } from "Base/Sorts/DefaultSortHandler";
    import { IFilterExpressionOptions } from "Base/Rules/ExpressionHelperOptions";
    import { IUserContext } from "UserContext/UserContextHandler";
    export default class PluginOptions implements ISearchBoxPluginOptions {
        analyticsCustomMetadata: any;
        analyticsEndpointUri: string;
        boostExpressions: string;
        clientLanguageFieldName: string;
        clientLanguageName: string;
        componentRefreshCallback: any;
        defaultSortType: string;
        defaultSortField: string;
        defaultSortCriteriaNoSpace: string;
        defaultSortCriteriaLowercase: string;
        enableClientSideLogging: boolean;
        externalCollections: Array<string>;
        externalSources: Array<string>;
        externalSourcesFromCurrentTab: Array<string>;
        externalCollectionsFromCurrentTab: Array<string>;
        filterExpression: string;
        filterResultOnLatestVersion: boolean;
        filterResultsOnCurrentCulture: boolean;
        indexSourceName: string;
        isEditingInPageEditor: boolean;
        isInitialized: boolean;
        isPreviewingInPageEditor: boolean;
        isPreviewingInPageEditorWithSimulatedDevice: boolean;
        keepOmniboxSuggestionsProvidersDefaultOrdering: boolean;
        latestVersionFieldName: string;
        omniboxDataRowIndexCounter: number;
        pageFullPath: string;
        pageName: string;
        restEndpointUri: string;
        resultListInfiniteScrollContainer: any;
        searchboxPlaceholderText: string;
        searchRedirectionUrl: string;
        searchRedirectionItemName: string;
        sendToSitecoreAnalytics: boolean;
        sitecoreItemId: string;
        sitecoreItemUri: string;
        siteName: string;
        userContext: IUserContext;
        constructor();
    }
    export interface ISearchBoxPluginOptions extends IPluginOptions, ISitecoreEndpointConfiguration {
        searchRedirectionItemName: string;
        searchRedirectionUrl: string;
    }
    export interface IPluginOptions extends IFilterExpressionOptions, IDefaultSortOptions, ISitecoreAnalyticsHandlerOptions {
        analyticsCustomMetadata: any;
        componentRefreshCallback: any;
        enableClientSideLogging: boolean;
        isEditingInPageEditor: boolean;
        isInitialized: boolean;
        isPreviewingInPageEditor: boolean;
        isPreviewingInPageEditorWithSimulatedDevice: boolean;
        keepOmniboxSuggestionsProvidersDefaultOrdering: boolean;
        omniboxDataRowIndexCounter: number;
        pageFullPath: string;
        pageName: string;
        restEndpointUri: string;
        resultListInfiniteScrollContainer: any;
        searchboxPlaceholderText: string;
        sitecoreItemUri: string;
        siteName: string;
        userContext: IUserContext;
    }
}
declare module "Base/Rules/ExpressionHelperUtilities" {
    export default class ExpressionHelperUtilities implements IExpressionHelperUtilities {
        getFilterExpression(fieldName: string, fieldValue: string | string[]): string;
        getExternalCollectionsExpression(externalCollections: string | string[]): string;
        getExternalSourcesExpression(externalSources: string | string[]): string;
        isDefined(property: string): boolean;
    }
    export interface IExpressionHelperUtilities {
        getFilterExpression(fieldName: string, fieldValue: string | string[]): string;
        getExternalCollectionsExpression(externalCollections: string | string[]): string;
        getExternalSourcesExpression(externalCollections: string | string[]): string;
        isDefined(option: any): boolean;
    }
}
declare module "Base/Rules/FilterExpressionHelper" {
    import { IFilterExpressionOptions, IContextFilterExpressionOptions, IExternalContentExpressionOptions } from "Base/Rules/ExpressionHelperOptions";
    import { IExpressionHelperUtilities } from "Base/Rules/ExpressionHelperUtilities";
    export default class FilterExpressionHelper implements IFilterExpressionHelper {
        private utilities;
        constructor(expressionHelperUtilities: IExpressionHelperUtilities);
        getFilterExpressions(options: IFilterExpressionOptions): string;
        getContextFilterExpressions(options: IContextFilterExpressionOptions): string;
        appendExternalContentToExpression(expression: string, options: IExternalContentExpressionOptions): string;
        private getAllExternalSources(externalSourcesOptions, externalContentFromCurrentTabOptions);
        private getAllExternalCollections(externalCollectionsOptions, externalContentFromCurrentTabOptions);
        private hasExternalContentSpecified(options);
    }
    export interface IFilterExpressionHelper {
        getContextFilterExpressions(options: IContextFilterExpressionOptions): string;
        appendExternalContentToExpression(expression: string, options: IExternalContentExpressionOptions): string;
    }
}
declare module "Base/Rules/SearchExpressionsHelper" {
    import { ISearchFilterExpressionOptions, ISearchBoostExpressionOptions, ISourcesExpressionOptions, IExternalCollectionsExpressionOptions, IExternalContentFromCurrentTabOptions } from "Base/Rules/ExpressionHelperOptions";
    import { IExpressionHelperUtilities } from "Base/Rules/ExpressionHelperUtilities";
    export default class SearchExpressionHelper implements ISearchExpressionHelper {
        private utilities;
        constructor(expressionHelperUtilities: IExpressionHelperUtilities);
        getSourcesAndCollectionsExpression(collectionsOptions: IExternalCollectionsExpressionOptions, sourcesOptions: ISourcesExpressionOptions, externalContentFromCurrentTab: IExternalContentFromCurrentTabOptions): string;
        getSearchFilterExpression(options: ISearchFilterExpressionOptions, externalContentFromCurrentTab: IExternalContentFromCurrentTabOptions): string;
        getSearchBoostExpression(options: ISearchBoostExpressionOptions): string;
        getSourcesExpression(sourcesExpressionOptions: ISourcesExpressionOptions, externalContentFromCurrentTab: IExternalContentFromCurrentTabOptions): string;
        private getAllExternalCollections(externalCollectionsOptions, externalContentFromCurrentTabOptions);
    }
    export interface ISearchExpressionHelper {
        getSourcesAndCollectionsExpression(collectionsOptions: IExternalCollectionsExpressionOptions, sourcesOptions: ISourcesExpressionOptions, externalContentFromCurrentTabOptions: IExternalContentFromCurrentTabOptions): string;
        getSearchBoostExpression(options: ISearchBoostExpressionOptions): string;
        getSearchFilterExpression(options: ISearchFilterExpressionOptions, externalContentFromCurrentTab: IExternalContentFromCurrentTabOptions): string;
        getSourcesExpression(options: ISourcesExpressionOptions, externalContentFromCurrentTabOptions: IExternalContentFromCurrentTabOptions): string;
    }
}
declare module "Base/Rules/ExpressionsHelper" {
    import { IFilterExpressionHelper } from "Base/Rules/FilterExpressionHelper";
    import { ISearchExpressionHelper } from "Base/Rules/SearchExpressionsHelper";
    import { ISearchExpressionOptions, IFilterExpressionOptions } from "Base/Rules/ExpressionHelperOptions";
    export default class ExpressionsHelper implements IExpressionsHelper {
        private filterExpressionHelper;
        private searchExpressionHelper;
        constructor(filterExpressionHelper?: IFilterExpressionHelper, searchExpressionHelper?: ISearchExpressionHelper);
        getFilterExpression(options: IFilterExpressionOptions): string;
        getSearchExpression(options: ISearchExpressionOptions): string;
    }
    export interface IExpressionsHelper {
        getFilterExpression(options: IFilterExpressionOptions): string;
        getSearchExpression(options: ISearchExpressionOptions): string;
    }
}
declare module "Base/OmniboxResultList/OmniboxResultListHandler" {
    import Coveo = require("coveo-search-ui");
    import { IOmniboxResultListOptions } from "Base/OmniboxResultList/OmniboxResultList";
    export default class OmniboxResultListHandler {
        static omniboxDataRowIndexCounter: number;
        static getOmniboxDataRowIndex(): number;
        onOmniboxRowClicked(result: Coveo.IQueryResult): void;
        buildOmniboxContent(results: Array<Coveo.IQueryResult>, options: IOmniboxResultListOptions): HTMLElement;
        populateOmniboxResultList(populateOmniboxObject: Coveo.IPopulateOmniboxEventArgs, options: IOmniboxResultListOptions, queryController: Coveo.QueryController): void;
        private executeSearchQuery(query);
        private getResultContainer(captionText);
        private getIcon();
        private getCaption(captionText);
    }
}
declare module "Base/OmniboxResultList/OmniboxResultList" {
    import * as Coveo from "coveo-search-ui";
    import Component = Coveo.Component;
    export class OmniboxResultList extends Component {
        element: HTMLElement;
        options: any;
        static ID: string;
        static options: IOmniboxResultListOptions;
        private omniboxResultListHandler;
        constructor(element: HTMLElement, options?: any, bindings?: Coveo.IComponentBindings);
        private bindEnterToSearchButton();
        private populateOmnibox(populateOmniboxObject);
        private initializeOmniboxDataRowIndex(bindings);
    }
    export interface IOmniboxResultListOptions {
        id?: string;
        headerTitle: string;
        queryExpression: string;
        numberOfResults: number;
        omniboxDataRowIndex: number;
        resultTemplateId: string;
    }
}
declare module "Base/Logger" {
    export default class Logger {
        private enableClientSideLogging;
        constructor(enableClientSideLogging: boolean);
        log(message: string): void;
    }
}
declare module "Base/CoveoForSitecoreBase" {
    import * as Coveo from "coveo-search-ui";
    import { IPluginOptions } from "Base/PluginOptions";
    import { IExpressionsHelper } from "Base/Rules/ExpressionsHelper";
    import { IOmniboxResultListOptions } from "Base/OmniboxResultList/OmniboxResultList";
    import Logger from "Base/Logger";
    import OmniboxResultListHandler from "Base/OmniboxResultList/OmniboxResultListHandler";
    export default class CoveoForSitecoreBase {
        element: HTMLElement;
        domElement: Coveo.Dom;
        options: IPluginOptions;
        omniboxResultListHandler: OmniboxResultListHandler;
        logger: Logger;
        expressionsHelper: IExpressionsHelper;
        private sitecoreAnalyticsHandler;
        private defaultSortHandler;
        private context;
        private isInPageEditorCssClass;
        private isEditingInPageEditorCssClass;
        private isPreviewingInPageEditorCssClass;
        private isPreviewingInPageEditorWithSimulatedDeviceCssClass;
        constructor(searchComponent: HTMLElement, options: IPluginOptions, defaultOptions: IPluginOptions);
        initialize(): void;
        doPostInitializationActions(): void;
        initializeSearchOptions(): void;
        postAnalytics(eventAction: string, eventType: string, eventData: any): void;
        addPageEditorCssClasses(): void;
        addResultListHeaderCssClasses(): void;
        getFilterExpressions(): string;
        registerSearchEvents(): void;
        isInPageEditor(): boolean;
        configureOmnibox(options: IOmniboxResultListOptions): void;
        private trySetOriginContextInUsageAnalytics();
        private addContextToQuery(queryBuilder);
        private getOptionsWithTabExternalContent(currentTabId?);
        private generatePopulateOmniboxFunction(options);
        private getDomElementsMatchingSelector(querySelector);
    }
}
declare module "Base/Tabs/TabsBinding" {
    export interface IBinding {
        tabNot: Array<string>;
    }
    export default class TabsBinding {
        private searchExpressionHelper;
        private bindings;
        excludeItemsIdsInTab(elementIds: Array<string>, tabId: string): void;
        applyBindings(): void;
        private getElementBinding;
        private elementFound;
        private initBinding;
        private applyBinding;
        private addExcludeFromTabTag;
    }
}
declare module "Base/Searchbox" {
    import { ISearchBoxPluginOptions } from "Base/PluginOptions";
    import CoveoForSitecoreBase from "Base/CoveoForSitecoreBase";
    export default class Searchbox extends CoveoForSitecoreBase {
        private searchBoxOptions;
        constructor(searchComponent: HTMLElement, searchBoxPluginOptions: ISearchBoxPluginOptions, defaultSearchBoxPluginOptions: ISearchBoxPluginOptions);
        initialize(): void;
    }
}
declare module "Base/Recommendations/IRelatedQueryOptions" {
    import { ISitecoreAnalyticsHandlerOptions } from "Base/Analytics/SitecoreAnalyticsHandler";
    import { IDefaultSortOptions } from "Base/Sorts/DefaultSortHandler";
    import { ICurrentCultureOptions } from "Base/Rules/ExpressionHelperOptions";
    export interface IRelatedQueryOptions extends IDefaultSortOptions, ISitecoreAnalyticsHandlerOptions, ICurrentCultureOptions {
    }
}
declare module "ICoveoForSitecore" {
    import { IPluginOptions } from "Base/PluginOptions";
    import CoveoForSitecoreBase from "Base/CoveoForSitecoreBase";
    import TabsBinding from "Base/Tabs/TabsBinding";
    import SearchEndpointHelperComponent from "Base/SearchEndpointHelper";
    import { IUserContextHandler } from "UserContext/UserContextHandler";
    import { IRelatedQueryOptions } from "Base/Recommendations/IRelatedQueryOptions";
    export var plugin: CoveoForSitecoreBase;
    export const userContext: IUserContextHandler;
    export const componentsOptions: IPluginOptions;
    export const tabsBinding: TabsBinding;
    export const SearchEndpointHelper: SearchEndpointHelperComponent;
    export const defaults: IPluginOptions;
    export function initializeSearch(searchComponent: HTMLElement, options: IPluginOptions): any;
    export function initializeSearchbox(searchComponent: HTMLElement, options: IPluginOptions): any;
    export function initRecommendations(element: HTMLElement): void;
    export function initRelatedQuery(element: HTMLElement, searchInterfaceElement?: HTMLElement, userContext?: any, options?: IRelatedQueryOptions): void;
}
declare module "CoveoForSitecoreUserContext" {
    import { IUserContextHandler } from "UserContext/UserContextHandler";
    import CoveoForSitecoreUserContextHandlerComponent from "UserContext/UserContextHandler";
    export const CoveoForSitecoreUserContextHandler: typeof CoveoForSitecoreUserContextHandlerComponent;
    export const handler: IUserContextHandler;
}
